@@ -51,7 +51,7 @@ from typing import (
 )
 
 _T = TypeVar("_T")
-UnfoldResult = Union[Result[_T, InvalidType], Result[_T, InvalidType]]
+UnfoldResult = Result[_T, InvalidType]  # type: ignore[misc]
 
 
 @dataclass(frozen=True)
